@@ -1,7 +1,7 @@
 next_n_years <-
 function(x = Sys.Date(),
            n = 1, 
-           part = c("all", "start", "end", "sequence", "length"),
+           part = getOption("timeperiodsR.parts"),
            include_current = F){
     
     if ( ! "Date" %in% class(x) ) {
@@ -12,11 +12,11 @@ function(x = Sys.Date(),
     stop  <- ceiling_date( x, unit = "year" ) + years(n) - days(1)
     out   <- custom_period(start, stop)
     
-    part <- match.arg(part)
+    part <- match.arg(part, getOption("timeperiodsR.parts"))
     
-    if ( part %in% c("start", "end", "sequence", "length") ) {
-      return(out[[part]]) 
-    } else {
+    if ( part == "all" ) {
       return(out) 
+    } else {
+      return(out[[part]]) 
     } 
   }
